import click
import json
from . import fcm

cli = click.Group()


@cli.command()
@click.option("--t", required=True, help="Enter push token.")
@click.option("--c", type=click.Path(exists=True), default='credentials.json',
              required=False, help="Enter credentials path.")
@click.option("--n", type=click.Path(exists=True), default='notification.json',
              required=False, help="Enter credentials path.")
def send(t, c, n):
    fcm.setup(c)
    data = {
        "push-message": json.dumps(json.load(open(n)))
    }
    fcm.send_message(t, data)
    click.secho("Completed!", fg='green')



import firebase_admin
from firebase_admin import messaging, credentials


def setup(service_account_key_file):
    cred = credentials.Certificate(service_account_key_file)
    firebase_admin.initialize_app(cred)


# https://firebase.google.com/docs/cloud-messaging/send-message#python
def send_message(registration_token, data):
    # See documentation on defining a message payload.
    message = messaging.Message(
        data=data,
        token=registration_token,
    )
    # Send a message to the device corresponding to the provided
    # registration token.
    response = messaging.send(message)
    # Response is a message ID string.
    print('Successfully sent message:', response)



from setuptools import setup, find_packages

long_description = 'Package made for testing push notification.'

setup(
    name='gpns',
    version='1.1.1',
    author='Ashish Sahu',
    author_email='ashish.sahu@enfec.com',
    url='https://github.com/enfec/gpns',
    description='Package for test firebase message.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'gpns = gpns.main:cli'
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords='python package gpns',
    install_requires=[
        'firebase-admin==6.2.0',
        'click==8.1.7',
    ],
    include_package_data=True,
    zip_safe=False
)
